import { TokenType } from "@prisma/client"
import jwt from "jsonwebtoken"
import errors from "../errors"
import jwtVerifyCatch from "../jwtVerifyCatch"
import { NextApiRequest, NextApiResponse } from "next"
import sendError from "./sendError"

async function checkTokenIsValid(
  req: NextApiRequest,
  res: NextApiResponse,
  rawToken: [string, TokenType],
  next: (tokenBody: jwt.JwtPayload) => void
) {
  const [tokenValue, tokenType] = rawToken

  // Verify the token and get the payload
  let tokenData: string | jwt.JwtPayload
  try {
    tokenData = jwt.verify(
      tokenValue,
      process.env.ACCESS_TOKEN_SECRET as string
    )
  } catch (err: any) {
    // Deal with the problem in more detail
    return sendError(req, res, jwtVerifyCatch(tokenType, err))
  }
  // Making sure the token data is not a string (because it should be an object)
  if (typeof tokenData === "string")
    return sendError(req, res, errors.tokenWasString(tokenType, tokenValue))

  return next(tokenData)
}

export default checkTokenIsValid
