import { Player, Token, TokenType } from "@prisma/client"
import jwt from "jsonwebtoken"
import prisma from "../../prisma"

const tokenLifetime = {
  REFRESH: 172800,
  ACCESS: 15,
}

export default async function createTokenDB(
  player: Player,
  newTokenType: TokenType,
  next: (token: [string, Token]) => void
) {
  // Create token entry in DB
  const newTokenDB = await prisma.token.create({
    data: {
      type: newTokenType,
      // expires: new Date(Date.now() + tokenLifetime[newTokenType] + "000"),
      owner: {
        connect: {
          id: player.id,
        },
      },
    },
  })

  // Sign a new access token
  const newToken = jwt.sign(
    { id: newTokenDB.id },
    process.env.TOKEN_SECRET as string,
    { expiresIn: tokenLifetime[newTokenType] }
  )

  return next([newToken, newTokenDB])
}
