import prisma from "../../prisma"
import jwt from "jsonwebtoken"
import { Token, TokenType } from "@prisma/client"
import errors from "../errors"
import sendError from "./sendError"
import { NextApiRequest, NextApiResponse } from "next"

async function getTokenDB(
  req: NextApiRequest,
  res: NextApiResponse,
  tokenBody: jwt.JwtPayload,
  tokenType: TokenType,
  next: (tokenDB: Token) => void
) {
  // Find refresh token in DB
  const tokenDB = await prisma.token.findUnique({
    where: {
      id: tokenBody.id,
    },
  })
  if (!tokenDB) return sendError(req, res, errors.tokenNotFound(tokenType))

  if (tokenDB.used) return sendError(req, res, errors.tokenUsed)

  await prisma.token.update({
    where: {
      id: tokenBody.id,
    },
    data: {
      used: true,
    },
  })

  // await logging('Old token has been invalidated.', ['debug'], req)

  return next(tokenDB)
}

export default getTokenDB
